==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/bs.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Nemoguće slanje emaila slijedećim korisnicima: %s",
    "Turned on maintenance mode" : "Upaljen modus održavanja",
    "Turned off maintenance mode" : "Ugašen modus održavanja",
    "Updated database" : "Aktualizirana baza podataka",
    "Checked database schema update" : "Provjereno aktualiziranje šeme baze podataka",
    "Checked database schema update for apps" : "Provjereno ažuriranje šeme baze podataka za aplikacije",
    "Updated \"%s\" to %s" : "Aktualizirano \"%s\" do %s",
    "No image or file provided" : "Ne postoji predviđena slika ili datoteka",
    "Unknown filetype" : "Nepoznat tip datoteke",
    "Invalid image" : "Nevažeća datoteka",
    "No temporary profile picture available, try again" : "Trenutna slika profila nije dostupna, pokušajte ponovo",
    "Sunday" : "Nedjelja",
    "Monday" : "Ponedjeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Srijeda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sun." : "Ned.",
    "Mon." : "Pon.",
    "Tue." : "Ut.",
    "Wed." : "Sri.",
    "Thu." : "Čet.",
    "Fri." : "Pet.",
    "Sat." : "Sub.",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mart",
    "April" : "April",
    "May" : "Maj",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "Avgust",
    "September" : "Septembar",
    "October" : "Oktobar",
    "November" : "Novembar",
    "December" : "Decembar",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Avg.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Settings" : "Postavke",
    "Saving..." : "Spašavam...",
    "Couldn't send reset email. Please contact your administrator." : "Slanje emaila resetovanja nije moguće. Molim kontaktirajte administratora.",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Veza za resetovanje vaše lozinke poslana je na vašu adresu e-pošte. Ako je ne primite u nekom razumnom vremenskom roku, provjerite svoje spam/junk direktorij. <br> Ako nije tamo, kontaktirajte vašeg lokalnog administratora.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vaše datoteke su šifrirane. Ako niste aktivirali povratni ključ, neećete imati mogućnost povratka vaših podataka nakon što vaša lozinka bude resetovana.<br />Ako niste sigurni šta učiniti, prije nego nastavite, molimo kontaktirajte vašeg administratora. <br />Želite li zaista nastaviti?",
    "I know what I'm doing" : "Ja znam šta radim",
    "Password can not be changed. Please contact your administrator." : "Lozinku ne može biti promjenuta. Molimo kontaktirajte vašeg administratora.",
    "No" : "Ne",
    "Yes" : "Da",
    "Choose" : "Izaberite",
    "Error loading file picker template: {error}" : "Pogrešno učitavanje šablona za izabir datoteke: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Pogrešno učitavanje šablona za poruke: {error}",
    "read-only" : "samo-čitljivo",
    "One file conflict" : "Konflikt jedne datoteke",
    "New Files" : "Nove datoteke",
    "Already existing files" : "Postojeće datoteke",
    "Which files do you want to keep?" : "Koje datoteke želite zadržati?",
    "If you select both versions, the copied file will have a number added to its name." : "Ako odaberete obe verzije, kopirana datoteka će imati broj dodan uz njeno ime.",
    "Cancel" : "Odustani",
    "Continue" : "Nastavi",
    "(all selected)" : "(sve odabrano)",
    "({count} selected)" : "({count} odabranih)",
    "Error loading file exists template" : "Pogrešno učitavanje postojece datoteke šablona",
    "Very weak password" : "Veoma slaba lozinka",
    "Weak password" : "Slaba lozinka",
    "So-so password" : "Tu-i-tamo lozinka",
    "Good password" : "Dobra lozinka",
    "Strong password" : "Jaka lozinka",
    "Error occurred while checking server setup" : "Došlo je do pogreške prilikom provjere serverskih postavki",
    "Shared" : "Podijeljen",
    "Shared with {recipients}" : "Podijeljen sa {recipients}",
    "Error" : "Greška",
    "Error while sharing" : "Greška pri dijeljenju",
    "Error while unsharing" : "Ggreška pri prestanku dijeljenja",
    "Error while changing permissions" : "Greška pri mijenjanju dozvola",
    "Error setting expiration date" : "Pogrešno postavljanje datuma isteka",
    "The public link will expire no later than {days} days after it is created" : "Javna veza ističe najkasnije {days} dana nakon što je kreirana",
    "Set expiration date" : "Postavite datum isteka",
    "Expiration" : "Istek",
    "Expiration date" : "Datum isteka",
    "Sending ..." : "Slanje...",
    "Email sent" : "E-pošta poslana",
    "Resharing is not allowed" : "Ponovno dijeljenje nije dopušteno",
    "Share link" : "Podijelite vezu",
    "Link" : "Veza",
    "Password protect" : "Zaštitita lozinkom",
    "Password" : "Lozinka",
    "Choose a password for the public link" : "Izaberite lozinku za javnu vezu",
    "Allow editing" : "Dozvolite izmjenu",
    "Email link to person" : "Pošaljite osobi vezu e-poštom",
    "Send" : "Pošalji",
    "Shared with you and the group {group} by {owner}" : "Dijeljeno s vama i grupom {group} vlasnika {owner}",
    "Shared with you by {owner}" : "Podijeljeno sa vama od {owner}",
    "Shared in {item} with {user}" : "Podijeljeno u {item} s {user}",
    "group" : "grupa",
    "remote" : "daljinski",
    "notify by email" : "Obavijesti e-poštom",
    "Unshare" : "Prestani dijeliti",
    "can share" : "može dijeliti",
    "can edit" : "moće mijenjati",
    "create" : "kreiraj",
    "change" : "izmjeni",
    "delete" : "izbriši",
    "access control" : "Kontrola pristupa",
    "Share" : "Podijeli",
    "Warning" : "Upozorenje",
    "The object type is not specified." : "Vrsta objekta nije određena.",
    "Enter new" : "Unesi novi",
    "Delete" : "Izbriši",
    "Add" : "Dodaj",
    "Edit tags" : "Izmjeni oznake",
    "Error loading dialog template: {error}" : "Pogrešno učitavanje šablona dijaloga: {error}",
    "No tags selected for deletion." : "Nema odabranih oznaka za brisanje.",
    "unknown text" : "nepoznat tekst",
    "Hello world!" : "Halo svijete!",
    "sunny" : "sunčan",
    "Hello {name}, the weather is {weather}" : "Halo {name}, vrijeme je {weather}",
    "Updating {productName} to version {version}, this may take a while." : "Ažuriranje {productName} u verziiju {version}, to može potrajati neko vrijeme.",
    "Please reload the page." : "Molim, ponovno učitajte stranicu",
    "The update was unsuccessful. " : "Ažuriranje nije uspjelo.",
    "The update was successful. Redirecting you to ownCloud now." : "Ažuriranje je uspjelo. Preusmjeravam vas na ownCloud.",
    "Couldn't reset password because the token is invalid" : "Nemoguće resetiranje lozinke jer znak nije validan.",
    "Couldn't send reset email. Please make sure your username is correct." : "Slanje emaila resetovanja nije moguće. Osigurajte se da vam je ispravno korisničko ime.",
    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Slanje emaila resetovanja nije moguće jer za ovo korisničko ime ne postoji email adresa. Molim, kontaktirajte administratora.",
    "%s password reset" : "%s lozinka resetovana",
    "Use the following link to reset your password: {link}" : "Za resetovanje vaše lozinke koristite slijedeću vezu: {link}",
    "New password" : "Nova lozinka",
    "New Password" : "Nova Lozinka",
    "Reset password" : "Resetuj lozinku",
    "Personal" : "Osobno",
    "Users" : "Korisnici",
    "Apps" : "Aplikacije",
    "Admin" : "Admin",
    "Help" : "Pomoć",
    "Error loading tags" : "Greška pri učitavanju oznaka",
    "Tag already exists" : "Oznaka već postoji",
    "Error deleting tag(s)" : "Greška pri brisanju znaka(ova)",
    "Error tagging" : "Greška pri označavanju",
    "Error untagging" : "Greška pri uklanjanju oznaka",
    "Error favoriting" : "Greška pri dodavanju u favorite",
    "Error unfavoriting" : "Greška pri uklanjanju iz favorita",
    "Access forbidden" : "Zabranjen pristup",
    "File not found" : "Datoteka nije pronađena",
    "The specified document has not been found on the server." : "Odabran dokument nije pronađen na serveru.",
    "You can click here to return to %s." : "Možete kliknuti ovdje da bih se vratili na %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hej,\n\nsamo da javim da je %s podjelio(la) %s s vama.\nPosjeti: %s\n\n",
    "The share will expire on %s." : "Podijeljeni resurs će isteći na %s.",
    "Cheers!" : "Cheers!",
    "Internal Server Error" : "Unutarnja Server Greška",
    "More details can be found in the server log." : "Više detalja se mogu naći u server zapisu (log).",
    "Technical details" : "Tehnički detalji",
    "Request ID: %s" : "Zahtjevaj ID: %s",
    "Code: %s" : "Kod (Code): %s",
    "Message: %s" : "Poruka: %s",
    "File: %s" : "Datoteka: %s",
    "Line: %s" : "Red: %s",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vaš direktorij podataka i datoteke vjerojatno se mogu pristupiti s interneta jer .htaccess datoteka ne radi.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Za informacije kako da valjano konfigurišete vaš server, molim pogledajte <a href=\"%s\" target=\"_blank\">dokumentaciju</a>.",
    "Create an <strong>admin account</strong>" : "Kreirajte <strong>administracioni račun</strong>",
    "Username" : "Korisničko ime",
    "Storage & database" : "Pohrana & baza podataka",
    "Data folder" : "Direktorij podataka",
    "Configure the database" : "Konfigurišite bazu podataka",
    "Only %s is available." : "Samo %s je dostupno.",
    "Database user" : "Korisnik baze podataka",
    "Database password" : "Lozinka baze podataka",
    "Database name" : "Naziv baze podataka",
    "Database tablespace" : "Tablespace (?) baze podataka",
    "Database host" : "Glavno računalo (host) baze podataka",
    "Finish setup" : "Završite postavke",
    "Finishing …" : "Završavanje...",
    "Log out" : "Odjava",
    "Search" : "Potraži",
    "Server side authentication failed!" : "Autentikacija na strani servera nije uspjela!",
    "Please contact your administrator." : "Molim kontaktirajte svog administratora.",
    "Log in" : "Prijava",
    "remember" : "zapamti",
    "Alternative Logins" : "Alternativne Prijave",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hej, <br><br> upravo vam javljam da je %s s vama podijelio <strong>%s</strong>.<br><a href=\"%s\">Pogledajte!</a><br><br>",
    "This ownCloud instance is currently in single user mode." : "Ova ownCloud instanca je trenutno u jednokorisničkom načinu rada.",
    "This means only administrators can use the instance." : "To znači da tu instancu mogu koristiti samo administratori.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktirajte svog administratora sistema ako se ova poruka ponavlja ili se pojavila neočekivano.",
    "Thank you for your patience." : "Hvala vam na strpljenju",
    "You are accessing the server from an untrusted domain." : "Pristupate serveru sa nepouzdane domene.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Molim kontaktirajte vašeg administratora. Ako ste vi administrator ove instance, konfigurišite postavku \"trusted_domain\" u config/config.php. Primjer konfiguracije ponuđen je u config/config.sample.php.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Ovisno o vašoj konfiguraciji, kao administrator vi biste također mogli koristiti dugme ispod za povjeru toj domeni.",
    "Add \"%s\" as trusted domain" : "Dodajte \"%s\" kao povjerenu/pouzdanu domenu.",
    "The theme %s has been disabled." : "Tema %s je onemogućena",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Prije nego nastavite, molim osigurajte se da su baza podataka, direktorij konfiguracije i direktorij podataka sigurnosno kopirani.",
    "Start update" : "Započnite ažuriranje",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Da biste izbjegli vremensko prekoračenje s većim instalacijama, možete pokrenuti slijedeću naredbu iz svoga instalacijskog direktorija:",
    "This page will refresh itself when the %s instance is available again." : "Ova stranica će se sama aktualizirati nakon što instanca %s postane ponovo dostupna."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/bs.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Nemoguće slanje emaila slijedećim korisnicima: %s",
    "Turned on maintenance mode" : "Upaljen modus održavanja",
    "Turned off maintenance mode" : "Ugašen modus održavanja",
    "Updated database" : "Aktualizirana baza podataka",
    "Checked database schema update" : "Provjereno aktualiziranje šeme baze podataka",
    "Checked database schema update for apps" : "Provjereno ažuriranje šeme baze podataka za aplikacije",
    "Updated \"%s\" to %s" : "Aktualizirano \"%s\" do %s",
    "No image or file provided" : "Ne postoji predviđena slika ili datoteka",
    "Unknown filetype" : "Nepoznat tip datoteke",
    "Invalid image" : "Nevažeća datoteka",
    "No temporary profile picture available, try again" : "Trenutna slika profila nije dostupna, pokušajte ponovo",
    "Couldn't reset password because the token is invalid" : "Nemoguće resetiranje lozinke jer znak nije validan.",
    "Couldn't send reset email. Please make sure your username is correct." : "Slanje emaila resetovanja nije moguće. Osigurajte se da vam je ispravno korisničko ime.",
    "%s password reset" : "%s lozinka resetovana",
    "Couldn't send reset email. Please contact your administrator." : "Slanje emaila resetovanja nije moguće. Molim kontaktirajte administratora.",
    "Sunday" : "Nedjelja",
    "Monday" : "Ponedjeljak",
    "Tuesday" : "Utorak",
    "Wednesday" : "Srijeda",
    "Thursday" : "Četvrtak",
    "Friday" : "Petak",
    "Saturday" : "Subota",
    "Sun." : "Ned.",
    "Mon." : "Pon.",
    "Tue." : "Ut.",
    "Wed." : "Sri.",
    "Thu." : "Čet.",
    "Fri." : "Pet.",
    "Sat." : "Sub.",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mart",
    "April" : "April",
    "May" : "Maj",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "Avgust",
    "September" : "Septembar",
    "October" : "Oktobar",
    "November" : "Novembar",
    "December" : "Decembar",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Avg.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Settings" : "Postavke",
    "Saving..." : "Spašavam...",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Veza za resetovanje vaše lozinke poslana je na vašu adresu e-pošte. Ako je ne primite u nekom razumnom vremenskom roku, provjerite svoje spam/junk direktorij. <br> Ako nije tamo, kontaktirajte vašeg lokalnog administratora.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Vaše datoteke su šifrirane. Ako niste aktivirali povratni ključ, neećete imati mogućnost povratka vaših podataka nakon što vaša lozinka bude resetovana.<br />Ako niste sigurni šta učiniti, prije nego nastavite, molimo kontaktirajte vašeg administratora. <br />Želite li zaista nastaviti?",
    "I know what I'm doing" : "Ja znam šta radim",
    "Password can not be changed. Please contact your administrator." : "Lozinku ne može biti promjenuta. Molimo kontaktirajte vašeg administratora.",
    "No" : "Ne",
    "Yes" : "Da",
    "Choose" : "Izaberite",
    "Error loading file picker template: {error}" : "Pogrešno učitavanje šablona za izabir datoteke: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Pogrešno učitavanje šablona za poruke: {error}",
    "read-only" : "samo-čitljivo",
    "One file conflict" : "Konflikt jedne datoteke",
    "New Files" : "Nove datoteke",
    "Already existing files" : "Postojeće datoteke",
    "Which files do you want to keep?" : "Koje datoteke želite zadržati?",
    "If you select both versions, the copied file will have a number added to its name." : "Ako odaberete obe verzije, kopirana datoteka će imati broj dodan uz njeno ime.",
    "Cancel" : "Odustani",
    "Continue" : "Nastavi",
    "(all selected)" : "(sve odabrano)",
    "({count} selected)" : "({count} odabranih)",
    "Error loading file exists template" : "Pogrešno učitavanje postojece datoteke šablona",
    "Very weak password" : "Veoma slaba lozinka",
    "Weak password" : "Slaba lozinka",
    "So-so password" : "Tu-i-tamo lozinka",
    "Good password" : "Dobra lozinka",
    "Strong password" : "Jaka lozinka",
    "Error occurred while checking server setup" : "Došlo je do pogreške prilikom provjere serverskih postavki",
    "Shared" : "Podijeljen",
    "Shared with {recipients}" : "Podijeljen sa {recipients}",
    "Error" : "Greška",
    "Error while sharing" : "Greška pri dijeljenju",
    "Error while unsharing" : "Ggreška pri prestanku dijeljenja",
    "Error setting expiration date" : "Pogrešno postavljanje datuma isteka",
    "The public link will expire no later than {days} days after it is created" : "Javna veza ističe najkasnije {days} dana nakon što je kreirana",
    "Set expiration date" : "Postavite datum isteka",
    "Expiration" : "Istek",
    "Expiration date" : "Datum isteka",
    "Choose a password for the public link" : "Izaberite lozinku za javnu vezu",
    "Sending ..." : "Slanje...",
    "Email sent" : "E-pošta poslana",
    "Resharing is not allowed" : "Ponovno dijeljenje nije dopušteno",
    "Share link" : "Podijelite vezu",
    "Link" : "Veza",
    "Password protect" : "Zaštitita lozinkom",
    "Password" : "Lozinka",
    "Allow editing" : "Dozvolite izmjenu",
    "Email link to person" : "Pošaljite osobi vezu e-poštom",
    "Send" : "Pošalji",
    "Shared with you and the group {group} by {owner}" : "Dijeljeno s vama i grupom {group} vlasnika {owner}",
    "Shared with you by {owner}" : "Podijeljeno sa vama od {owner}",
    "group" : "grupa",
    "remote" : "daljinski",
    "notify by email" : "Obavijesti e-poštom",
    "Unshare" : "Prestani dijeliti",
    "can share" : "može dijeliti",
    "can edit" : "moće mijenjati",
    "create" : "kreiraj",
    "change" : "izmjeni",
    "delete" : "izbriši",
    "access control" : "Kontrola pristupa",
    "Share" : "Podijeli",
    "Warning" : "Upozorenje",
    "Delete" : "Izbriši",
    "Rename" : "Preimenuj",
    "The object type is not specified." : "Vrsta objekta nije određena.",
    "Enter new" : "Unesi novi",
    "Add" : "Dodaj",
    "Edit tags" : "Izmjeni oznake",
    "Error loading dialog template: {error}" : "Pogrešno učitavanje šablona dijaloga: {error}",
    "No tags selected for deletion." : "Nema odabranih oznaka za brisanje.",
    "unknown text" : "nepoznat tekst",
    "Hello world!" : "Halo svijete!",
    "sunny" : "sunčan",
    "Hello {name}, the weather is {weather}" : "Halo {name}, vrijeme je {weather}",
    "Updating {productName} to version {version}, this may take a while." : "Ažuriranje {productName} u verziiju {version}, to može potrajati neko vrijeme.",
    "Please reload the page." : "Molim, ponovno učitajte stranicu",
    "The update was unsuccessful. " : "Ažuriranje nije uspjelo.",
    "The update was successful. Redirecting you to ownCloud now." : "Ažuriranje je uspjelo. Preusmjeravam vas na ownCloud.",
    "Personal" : "Osobno",
    "Users" : "Korisnici",
    "Apps" : "Aplikacije",
    "Admin" : "Admin",
    "Help" : "Pomoć",
    "Error loading tags" : "Greška pri učitavanju oznaka",
    "Tag already exists" : "Oznaka već postoji",
    "Error deleting tag(s)" : "Greška pri brisanju znaka(ova)",
    "Error tagging" : "Greška pri označavanju",
    "Error untagging" : "Greška pri uklanjanju oznaka",
    "Error favoriting" : "Greška pri dodavanju u favorite",
    "Error unfavoriting" : "Greška pri uklanjanju iz favorita",
    "Access forbidden" : "Zabranjen pristup",
    "File not found" : "Datoteka nije pronađena",
    "The specified document has not been found on the server." : "Odabran dokument nije pronađen na serveru.",
    "You can click here to return to %s." : "Možete kliknuti ovdje da bih se vratili na %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hej,\n\nsamo da javim da je %s podjelio(la) %s s vama.\nPosjeti: %s\n\n",
    "The share will expire on %s." : "Podijeljeni resurs će isteći na %s.",
    "Cheers!" : "Cheers!",
    "Internal Server Error" : "Unutarnja Server Greška",
    "More details can be found in the server log." : "Više detalja se mogu naći u server zapisu (log).",
    "Technical details" : "Tehnički detalji",
    "Request ID: %s" : "Zahtjevaj ID: %s",
    "Code: %s" : "Kod (Code): %s",
    "Message: %s" : "Poruka: %s",
    "File: %s" : "Datoteka: %s",
    "Line: %s" : "Red: %s",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vaš direktorij podataka i datoteke vjerojatno se mogu pristupiti s interneta jer .htaccess datoteka ne radi.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Za informacije kako da valjano konfigurišete vaš server, molim pogledajte <a href=\"%s\" target=\"_blank\">dokumentaciju</a>.",
    "Create an <strong>admin account</strong>" : "Kreirajte <strong>administracioni račun</strong>",
    "Username" : "Korisničko ime",
    "Storage & database" : "Pohrana & baza podataka",
    "Data folder" : "Direktorij podataka",
    "Configure the database" : "Konfigurišite bazu podataka",
    "Only %s is available." : "Samo %s je dostupno.",
    "Database user" : "Korisnik baze podataka",
    "Database password" : "Lozinka baze podataka",
    "Database name" : "Naziv baze podataka",
    "Database tablespace" : "Tablespace (?) baze podataka",
    "Database host" : "Glavno računalo (host) baze podataka",
    "Finish setup" : "Završite postavke",
    "Finishing …" : "Završavanje...",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hej, <br><br> upravo vam javljam da je %s s vama podijelio <strong>%s</strong>.<br><a href=\"%s\">Pogledajte!</a><br><br>",
    "Log out" : "Odjava",
    "Search" : "Potraži",
    "Server side authentication failed!" : "Autentikacija na strani servera nije uspjela!",
    "Please contact your administrator." : "Molim kontaktirajte svog administratora.",
    "Log in" : "Prijava",
    "Alternative Logins" : "Alternativne Prijave",
    "Use the following link to reset your password: {link}" : "Za resetovanje vaše lozinke koristite slijedeću vezu: {link}",
    "New password" : "Nova lozinka",
    "New Password" : "Nova Lozinka",
    "Reset password" : "Resetuj lozinku",
    "This ownCloud instance is currently in single user mode." : "Ova ownCloud instanca je trenutno u jednokorisničkom načinu rada.",
    "This means only administrators can use the instance." : "To znači da tu instancu mogu koristiti samo administratori.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktirajte svog administratora sistema ako se ova poruka ponavlja ili se pojavila neočekivano.",
    "Thank you for your patience." : "Hvala vam na strpljenju",
    "You are accessing the server from an untrusted domain." : "Pristupate serveru sa nepouzdane domene.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Ovisno o vašoj konfiguraciji, kao administrator vi biste također mogli koristiti dugme ispod za povjeru toj domeni.",
    "Add \"%s\" as trusted domain" : "Dodajte \"%s\" kao povjerenu/pouzdanu domenu.",
    "The theme %s has been disabled." : "Tema %s je onemogućena",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Prije nego nastavite, molim osigurajte se da su baza podataka, direktorij konfiguracije i direktorij podataka sigurnosno kopirani.",
    "Start update" : "Započnite ažuriranje",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Da biste izbjegli vremensko prekoračenje s većim instalacijama, možete pokrenuti slijedeću naredbu iz svoga instalacijskog direktorija:",
    "This page will refresh itself when the %s instance is available again." : "Ova stranica će se sama aktualizirati nakon što instanca %s postane ponovo dostupna.",
    "Error loading file picker template: {error}" : "Pogrešno učitavanje šablona za izabir datoteke: {error}",
    "You can click here to return to %s." : "Možete kliknuti ovdje da bih se vratili na %s.",
    "Password can not be changed. Please contact your administrator." : "Lozinku ne može biti promjenuta. Molimo kontaktirajte vašeg administratora."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
